@@ -2,7 +2,7 @@ from dataclasses import dataclass
 from pathlib import Path
 from typing import List
 
-from path_info import PathInfo
+from .path_info import PathInfo
 
 
 @dataclass
